@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 # vim:ts=4:sw=4:softtabstop=4:smarttab:expandtab
 
@@ -25,10 +25,6 @@
 # CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY
 # WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-from __future__ import unicode_literals, division, absolute_import, print_function
-
-import sys
-import os
 from quickparser import QuickXHTMLParser
 from preferences import JSONPrefs
 from pluginhunspell import HunspellChecker
@@ -38,12 +34,12 @@ class ContainerException(Exception):
 
 class OutputContainer(object):
 
-    def __init__(self, wrapper,  debug = False):
+    def __init__(self, wrapper, debug=False):
         self._debug = debug
         self._w = wrapper
-        self.qp=QuickXHTMLParser()
-        self.hspell=HunspellChecker(wrapper.get_hunspell_path())
-        self.dictionary_dirs=wrapper.get_dictionary_dirs()
+        self.qp = QuickXHTMLParser()
+        self.hspell = HunspellChecker(wrapper.get_hunspell_path())
+        self.dictionary_dirs = wrapper.get_dictionary_dirs()
         self._prefs_store = JSONPrefs(wrapper.plugin_dir, wrapper.plugin_name)
 
     def getPrefs(self):
@@ -59,6 +55,21 @@ class OutputContainer(object):
     def epub_version(self):
         return self._w.getepubversion()
 
+    def epub_is_standard(self):
+        return self._w.epub_is_standard()
+
+    @property
+    def sigil_ui_lang(self):
+        if self._w.sigil_ui_lang is None:
+            return 'en'
+        return self._w.sigil_ui_lang
+
+    @property
+    def sigil_spellcheck_lang(self):
+        if self._w.sigil_spellcheck_lang is None:
+            return 'en_US'
+        return self._w.sigil_spellcheck_lang
+
 
 # OPF Acess and Manipulation Routines
 
@@ -70,6 +81,12 @@ class OutputContainer(object):
     def getpagemapid(self):
         return self._w.getpagemapid()
 
+# nav access routines
+
+    def getnavid(self):
+        return self._w.getnavid()
+
+
 # spine get and access routines
 
     def getspine(self):
@@ -93,7 +110,7 @@ class OutputContainer(object):
         return self._w.guide
 
 # bindings get
-   # New for epub3
+    # New for epub3
     def getbindings_epub3(self):
         # bindings is an ordered list of tuples (media-type, handler)
         return self._w.getbindings_epub3()
@@ -126,7 +143,7 @@ class OutputContainer(object):
 
     def text_iter(self):
         # yields manifest id, href in spine order plus any non-spine items
-        text_set = set([k for k,v in self._w.id_to_mime.items() if v == 'application/xhtml+xml'])
+        text_set = set([k for k, v in self._w.id_to_mime.items() if v == 'application/xhtml+xml'])
         for id, linear, properties in self._w.spine:
             if id in text_set:
                 text_set -= set([id])
@@ -156,7 +173,7 @@ class OutputContainer(object):
         # yields manifest id, href, and mimetype
         for id in sorted(self._w.id_to_mime):
             mime = self._w.id_to_mime[id]
-            if mime.find('font-') > -1 or mime.endswith('-ttf') or mime.endswith('truetype') or mime.endswith('opentype'):
+            if 'font-' in mime or 'truetype' in mime or 'opentype' in mime or mime.startswith('font/'):
                 href = self._w.id_to_href[id]
                 yield id, href, mime
 
@@ -184,7 +201,7 @@ class OutputContainer(object):
             href = self._w.id_to_href[id]
             yield id, linear, href
 
-   # New for epub3
+    # New for epub3
     def spine_epub3_iter(self):
         # yields spine idref, linear(yes,no,None), properties, href in spine order
         for (id , linear, properties) in self._w.spine:
@@ -223,15 +240,11 @@ class OutputContainer(object):
         for book_href in self._w.selected:
             id_type = 'other'
             id = book_href
-            href = book_href
-            if href.startswith('OEBPS/'):
-                href = href[6:]
-            if href in self._w.href_to_id:
-                id = self._w.href_to_id[href]
+            if book_href in self._w.bookpath_to_id:
                 id_type = 'manifest'
+                id = self._w.bookpath_to_id[book_href]
             yield id_type, id
 
-
     # miscellaneous routines
 
     # build the current opf incorporating all changes to date and return it
@@ -242,11 +255,18 @@ class OutputContainer(object):
     def copy_book_contents_to(self, destdir):
         self._w.copy_book_contents_to(destdir)
 
-
     # get a list of the directories that contain Sigil's hunspell dictionaries
     def get_dictionary_dirs(self):
         return self._w.get_dictionary_dirs()
 
+    # get status of epub file open inside of Sigil
+    def get_epub_is_modified(self):
+        return self._w.epub_isDirty
+
+    # get path to currently open epub or an inside Sigil or empty string if unsaved
+    def get_epub_filepath(self):
+        return self._w.epub_filepath
+
 
     # functions for converting from  manifest id to href, basename, mimetype etc
     def href_to_id(self, href, ow=None):
@@ -276,3 +296,96 @@ class OutputContainer(object):
     def id_to_overlay(self, id, ow=None):
         return self._w.map_id_to_over.get(id, ow)
 
+
+    # New in Sigil 1.1
+    # ----------------
+
+    # returns "light" or "dark"
+    def colorMode(self):
+        return self._w.colorMode()
+
+    # returns color as css or javascript hex color string "#xxxxxx"
+    # acccepts the following color roles in a case insensitive manner:
+    #    "Window", "Base", "Text", "Highlight", "HighlightedText"
+    def color(self, role):
+        return self._w.color(role)
+
+    # New in Sigil 1.0
+    # ----------------
+
+    # A book path (aka bookpath) is a unique relative path from the
+    # ebook root to a specific file.  As a relative path meant to
+    # be used in an href or src "link" it only uses forward slashes "/"
+    # as path separators.  Since all files exist inside the
+    # epub root (folder the epub was unzipped into), book paths will NEVER
+    # have or use "./" or "../" ie they are in always in canonical form
+
+    # For example under Sigil pre 1.0, all epubs were put into a standard
+    # structure.  Under this standard structure book paths would look like
+    # the following:
+    #   OEBPS/content.opf
+    #   OEBPS/toc.ncx
+    #   OEBPS/Text/Section0001.xhtml
+    #   OEBPS/Images/cover.jpg
+    #
+
+    # and src and hrefs always looked like the following:
+    #    from Section0001.xhtml to Section0002.xhtml: ../Text/Section0002.xhtml
+    #    from Section0001.xhtml to cover.jpg:         ../Images/cover.jpg
+    #    from content.opf to Section0001.xhtml        Text/Section0001.xhtml
+    #    from toc.ncx to Section0001.xhtml            Text/Section0001.xhtml
+
+    # Under Sigil 1.0 and later, the original epub structure can be preserved
+    # meaning that files like content.opf could be named package.opf, and be placed
+    # almost anyplace inside the epub.  This is true for almost all files.
+
+    # So to uniquely identify a file, you need to know the bookpath of the OPF
+    # and the manifest href to the specific file, or the path from the epub
+    # root to the file (ie. its bookpath)
+
+    # so the Sigil plugin interface for Sigil 1.0 has been extended to allow
+    # the plugin developer to more easily work with bookpaths, create links
+    # between bookpaths, etc.
+
+    # we will use the terms book_href (or bookhref) interchangeably
+    # with bookpath with the following convention:
+    #    - use book_href when working with "other" files outside the manifest
+    #    - use bookpath when working with files in the opf manifest
+    #    - use either when working with the OPF file as it is at the intersection
+
+    # returns the bookpath/book_href to the opf file
+    def get_opfbookpath(self):
+        return self._w.get_opfbookpath()
+
+    # returns the book path of the folder containing this bookpath
+    def get_startingdir(self, bookpath):
+        return self._w.get_startingdir(bookpath)
+
+    # return a bookpath for the file pointed to by the href
+    # from the specified bookpath starting directory
+    def build_bookpath(self, href, starting_dir):
+        return self._w.build_bookpath(href, starting_dir)
+
+    # returns the href relative path from source bookpath to target bookpath
+    def get_relativepath(self, from_bookpath, to_bookpath):
+        return self._w.get_relativepath(from_bookpath, to_bookpath)
+
+    # adds a new file to the *manifest* with the stated bookpath with the provided
+    # uniqueid, data, (and mediatype if specified)
+    def addbookpath(self, uniqueid, bookpath, data, mime=None):
+        return self._w.addbookpath(uniqueid, bookpath, data, mime)
+
+    # functions for converting from  manifest id to bookpath and back
+    def bookpath_to_id(self, bookpath, ow=None):
+        return self._w.map_bookpath_to_id(bookpath, ow)
+
+    def id_to_bookpath(self, id, ow=None):
+        return self._w.map_id_to_bookpath(id, ow)
+
+    # valid groups: Text, Styles, Images, Fonts, Audio, Video, ncx, opf, Misc
+    # returns a sorted folder list of ebook paths for a group
+    def group_to_folders(self, group, ow=None):
+        return self._w.map_group_to_folders(group, ow)
+
+    def mediatype_to_group(self, mediatype, ow=None):
+        return self._w.map_mediatype_to_group(mediatype, ow)
